@@ -130,42 +130,44 @@ r::List CCM_rcpp( std::string  pathIn,
                   bool         includeData,
                   bool         verbose );
 
-r::DataFrame Simplex_rcpp( std::string  pathIn,
-                           std::string  dataFile,
-                           r::DataFrame dataList,
-                           std::string  pathOut,
-                           std::string  predictFile,
-                           std::string  lib,
-                           std::string  pred, 
-                           int          E,
-                           int          Tp,
-                           int          knn,
-                           int          tau, 
-                           int          exclusionRadius, 
-                           std::string  columns,
-                           std::string  target,
-                           bool         embedded,
-                           bool         const_predict,
-                           bool         verbose );
+r::DataFrame Simplex_rcpp( std::string       pathIn,
+                           std::string       dataFile,
+                           r::DataFrame      dataList,
+                           std::string       pathOut,
+                           std::string       predictFile,
+                           std::string       lib,
+                           std::string       pred,
+                           int               E,
+                           int               Tp,
+                           int               knn,
+                           int               tau,
+                           int               exclusionRadius,
+                           std::string       columns,
+                           std::string       target,
+                           bool              embedded,
+                           bool              const_predict,
+                           bool              verbose,
+                           std::vector<bool> validLib );
 
-r::List SMap_rcpp( std::string  pathIn, 
-                   std::string  dataFile,
-                   r::DataFrame dataList,
-                   std::string  pathOut,
-                   std::string  predictFile,
-                   std::string  lib,
-                   std::string  pred, 
-                   int          E,
-                   int          Tp,
-                   int          knn,
-                   int          tau,
-                   double       theta,
-                   int          exclusionRadius, 
-                   std::string  columns,
-                   std::string  target,
-                   std::string  smapFile,
-                   std::string  jacobians,
-                   bool         embedded,
-                   bool         const_predict,
-                   bool         verbose );
+r::List SMap_rcpp( std::string       pathIn,
+                   std::string       dataFile,
+                   r::DataFrame      dataList,
+                   std::string       pathOut,
+                   std::string       predictFile,
+                   std::string       lib,
+                   std::string       pred,
+                   int               E,
+                   int               Tp,
+                   int               knn,
+                   int               tau,
+                   double            theta,
+                   int               exclusionRadius,
+                   std::string       columns,
+                   std::string       target,
+                   std::string       smapFile,
+                   //std::string       jacobians, // Rcpp 20 arg limit
+                   bool              embedded,
+                   bool              const_predict,
+                   bool              verbose,
+                   std::vector<bool> validLib );
 #endif
