@@ -43,7 +43,6 @@ class DataFrame {
 
     size_t maxRowPrint;
     bool   noTime;
-    bool   partialDataRowsDeleted;
 
 public:
     //-----------------------------------------------------------------
@@ -56,13 +55,13 @@ public:
     //-----------------------------------------------------------------
     DataFrame():
         n_rows( 0 ), n_columns( 0 ), elements( 0 ),
-        maxRowPrint( 10 ), noTime( false ), partialDataRowsDeleted( false ) {}
+        maxRowPrint( 10 ), noTime( false ) {}
 
     //-----------------------------------------------------------------
     // Load data from CSV file path/fileName, populate DataFrame
     //-----------------------------------------------------------------
     DataFrame( std::string path, std::string fileName, bool noTime = false ):
-        maxRowPrint( 10 ), noTime( noTime ), partialDataRowsDeleted( false )
+        maxRowPrint( 10 ), noTime( noTime )
     {
         ReadData( path, fileName );
         SetupDataFrame(); // Process parsedData into a DataFrame
@@ -73,7 +72,7 @@ public:
     //-----------------------------------------------------------------
     DataFrame( size_t rows, size_t columns ):
         n_rows( rows ), n_columns( columns ), elements( columns * rows ),
-        maxRowPrint( 10 ), noTime( false ), partialDataRowsDeleted( false ) {}
+        maxRowPrint( 10 ), noTime( false ) {}
 
     //-----------------------------------------------------------------
     // Empty DataFrame of size (rows, columns) with column names in a
@@ -82,7 +81,7 @@ public:
     DataFrame( size_t rows, size_t columns, std::string colNames ):
         n_rows( rows ), n_columns( columns ), elements( columns * rows ),
         columnNames( std::vector<std::string>(columns) ), maxRowPrint( 10 ),
-        noTime( false ), partialDataRowsDeleted( false )
+        noTime( false )
     {
         BuildColumnNameIndex( colNames );
     }
@@ -95,7 +94,7 @@ public:
                std::vector< std::string > columnNames ):
         n_rows( rows ), n_columns( columns ), elements( columns * rows ),
         columnNames( columnNames ), maxRowPrint( 10 ),
-        noTime( false ), partialDataRowsDeleted( false ) 
+        noTime( false ) 
     {
         BuildColumnNameIndex();
     }
@@ -139,9 +138,6 @@ public:
     size_t  MaxRowPrint() const { return maxRowPrint; }
     size_t &MaxRowPrint()       { return maxRowPrint; }
 
-    bool  PartialDataRowsDeleted() const { return partialDataRowsDeleted; }
-    bool &PartialDataRowsDeleted()       { return partialDataRowsDeleted; }
-
     //-----------------------------------------------------------------
     // Return column from index col
     //-----------------------------------------------------------------
@@ -379,56 +375,6 @@ public:
         }
     }
 
-    //-----------------------------------------------------------------
-    // Delete nrows from the top or bottom depending on tau
-    // Requires that rows are contiguous: [ 0 : nrows ]
-    //-----------------------------------------------------------------
-    void DeletePartialDataRows( size_t nrows, int tau ) {
-
-        // NOTE : Not thread safe : Call needs mutex wrap
-        
-        if ( nrows > n_rows ) {
-            std::stringstream errMsg;
-            errMsg << "DataFrame::DeletePartialDataRows() "
-                   << " nrows (" << nrows << " larger than DataFrame "
-                   << "NRows (" << n_rows << ")" << std::endl;
-            throw( std::runtime_error( errMsg.str() ) );
-        }
-
-        // Update n_rows
-        n_rows = n_rows - nrows;
-
-        // Update time
-        if ( time.size() ) {
-            if ( tau < 0 ) {
-                time.erase( time.begin(), time.begin() + nrows );
-            }
-            else {
-                time.erase( time.end() - nrows, time.end() );
-            }
-        }
-
-        // Copy elements into data
-        std::valarray< T > data( elements );
-
-        // Resize elements
-        size_t n_elements = elements.size() - nrows * n_columns;
-        elements.resize( n_elements );
-
-        // Copy non deleted data to resized elements. NOTE: Row major format
-        std::slice elements_i;
-        if ( tau < 0 ) {
-            elements_i = std::slice( nrows * n_columns, n_elements, 1 );
-        }
-        else {
-            elements_i = std::slice( 0, n_elements, 1 );
-        }
-
-        // Bogus cast for MSVC 
-        elements[ std::slice( 0, n_elements, 1 ) ] =
-            ( std::valarray< T > ) data[ elements_i ];
-    }
-
     //-----------------------------------------------------------------
     // Build Column Name Index( std::string colNames )
     //-----------------------------------------------------------------
