@@ -27,6 +27,11 @@ void EDM::PrepareEmbedding( bool checkDataRows ) {
         CheckDataRows( "PrepareEmbedding" );
     }
 
+    if ( parameters.validLib.size() ){
+        CheckValidLib( "PrepareEmbedding" );
+    }
+
+
     // 1) Extract or Embed() data into embedding
     if ( parameters.embedded ) {
         // data is a multivariable block, no embedding needed
@@ -184,6 +189,17 @@ void EDM::FindNeighbors() {
                 }
             }
 
+            // Conditional embedding : check row is valid lib if supplied
+            if ( parameters.validLib.size() ) {
+                if ( not parameters.validLib[ libRow ] ) {
+#ifdef PRINT_SKIP_ROWS
+                    std::cout << "Skipping row " << libRow  << std::endl;
+#endif
+                    
+                    continue;
+                }
+            }
+
             // Add this distance, libRow (nn) to the rowPairs
             rowPairs.push_back( std::make_pair( rowDist[ i ], rowLib[ i ] ) );
         }
